<?php

/*
 * clist xml ǡ륹ץ
 * $Id: updateall.php,v 1.2 2003/01/25 05:21:26 yuryu Exp $
 */

require_once("./settings.php");
require_once("./readxmls.php");

header("Content-Type: text/plain");

foreach($guild_list as $guild)
{
	echo "Parsing " . $guild['Xml'] . " ...";
	parse_xml($guild['Xml']);
	echo " done\n";
}

?>
